@@ -1,7 +1,9 @@
 package Log::ger::Output::LogDispatchOutput;
 
-our $DATE = '2017-08-03'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-02-18'; # DATE
+our $DIST = 'Log-ger-Output-LogDispatchOutput'; # DIST
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -21,9 +23,10 @@ sub get_hooks {
 
     return {
         create_logml_routine => [
-            __PACKAGE__, 50,
-            sub {
-                my %args = @_;
+            __PACKAGE__, # key
+            50,          # priority
+            sub {        # hook
+                my %hook_args = @_; # see Log::ger::Manual::Internals/"Arguments passed to hook"
 
                 my $logger = sub {
                     my ($ctx, $level, $msg) = @_;
@@ -31,16 +34,17 @@ sub get_hooks {
                     return if $level > $Log::ger::Current_Level;
 
                     # we can use init_args to store per-target stuffs
-                    $args{init_args}{_ld} ||= Log::Dispatch->new(
+                    $hook_args{init_args}{_ld} ||= Log::Dispatch->new(
                         outputs => [
-                            [
-                                $conf{output},
-                                min_level => 'warning',
-                                %{ $conf{args} || {} },
-                            ],
+                            $conf{_output} ? $conf{_output} :
+                                [
+                                    $conf{output},
+                                    min_level => 'warning',
+                                    %{ $conf{args} || {} },
+                                ],
                         ],
                     );
-                    $args{init_args}{_ld}->warning($msg);
+                    $hook_args{init_args}{_ld}->warning($msg);
                 };
                 [$logger];
             }],
@@ -62,7 +66,7 @@ Log::ger::Output::LogDispatchOutput - Send logs to a Log::Dispatch output
 
 =head1 VERSION
 
-This document describes version 0.002 of Log::ger::Output::LogDispatchOutput (from Perl distribution Log-ger-Output-LogDispatchOutput), released on 2017-08-03.
+This document describes version 0.003 of Log::ger::Output::LogDispatchOutput (from Perl distribution Log-ger-Output-LogDispatchOutput), released on 2020-02-18.
 
 =head1 SYNOPSIS
 
@@ -113,7 +117,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
